<?php
/**
 * About options
 *
 * @package Theme Palace
 * @subpackage Pikture Pro
 * @since Pikture Pro 1.0.0
 */

// Add featured section
$wp_customize->add_section( 'pikture_pro_about_section', array(
	'title'             => esc_html__( 'About','pikture-pro' ),
	'description'       => esc_html__( 'About section options works only on Front page. Images with ratio of 2:3 ( for e.g: 640px by 960px ) would look the best in this section.', 'pikture-pro' ),
	'panel'             => 'pikture_pro_front_page_panel',
) );

// About content enable control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[enable_about_section]', array(
	'sanitize_callback' => 'pikture_pro_sanitize_switch_control',
	'default'          	=> $options['enable_about_section'],
) );

$wp_customize->add_control( new Pikture_Pro_Switch_Control( $wp_customize, 'pikture_pro_theme_options[enable_about_section]', array(
	'label'             => esc_html__( 'About Section:', 'pikture-pro' ),
	'section'           => 'pikture_pro_about_section',
	'on_off_label' 		=> pikture_pro_switch_options(),
) ) );

// About content type control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[about_content_type]', array(
	'sanitize_callback' => 'pikture_pro_sanitize_select',
	'default'          	=> $options['about_content_type'],
) );

$wp_customize->add_control( 'pikture_pro_theme_options[about_content_type]', array(
	'label'             => esc_html__( 'Content Type:', 'pikture-pro' ),
	'section'           => 'pikture_pro_about_section',
	'type'				=> 'radio',
	'active_callback' 	=> 'pikture_pro_is_about_enable',
	'choices'			=> pikture_pro_featured_content_type(),
) );

/**
 * Content type: Custom.
 */
// About custom title control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[about_custom_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'          	=> $options['about_custom_title'],
	'transport'			=> 'postMessage'
) );

$wp_customize->add_control( 'pikture_pro_theme_options[about_custom_title]', array(
	'label'             => esc_html__( 'Title:', 'pikture-pro' ),
	'section'           => 'pikture_pro_about_section',
	'active_callback' 	=> 'pikture_pro_is_about_custom_content_enable',
) );

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'pikture_pro_theme_options[about_custom_title]', array(
		'selector'            => '#about h2.entry-title',
		'render_callback'     => 'pikture_pro_about_custom_title_refresh',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

// About custom sub title control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[about_custom_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'          	=> $options['about_custom_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'pikture_pro_theme_options[about_custom_sub_title]', array(
	'label'             => esc_html__( 'Sub Title:', 'pikture-pro' ),
	'section'           => 'pikture_pro_about_section',
	'active_callback' 	=> 'pikture_pro_is_about_demo_content_disabled',
) );

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'pikture_pro_theme_options[about_custom_sub_title]', array(
		'selector'            => '#about span.sub-title',
		'render_callback'     => 'pikture_pro_about_custom_sub_title_refresh',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

// About custom content control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[about_custom_content]', array(
	'sanitize_callback' => 'pikture_pro_sanitize_html',
	'transport'			=> 'postMessage',
	'default'          	=> $options['about_custom_content'],
) );

$wp_customize->add_control( 'pikture_pro_theme_options[about_custom_content]', array(
	'label'           => esc_html__( 'Content:', 'pikture-pro' ),
	'description'     => esc_html__( 'HTML Allowed', 'pikture-pro' ),
	'section'         => 'pikture_pro_about_section',
	'active_callback' => 'pikture_pro_is_about_custom_content_enable',
	'type'            => 'textarea',
) );

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'pikture_pro_theme_options[about_custom_content]', array(
		'selector'            => '#about .entry-content',
		'render_callback'     => 'pikture_pro_about_custom_content_refresh',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

// About custom image control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[about_custom_image]', array(
	'sanitize_callback' => 'pikture_pro_sanitize_image',
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'pikture_pro_theme_options[about_custom_image]', array(
	'label'           => esc_html__( 'Image:', 'pikture-pro' ),
	'description'     => esc_html__( 'HTML Allowed', 'pikture-pro' ),
	'section'         => 'pikture_pro_about_section',
	'active_callback' => 'pikture_pro_is_about_custom_content_enable',
) ) );

// About custom link text control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[about_custom_btn_text]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'          	=> $options['about_custom_btn_text'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'pikture_pro_theme_options[about_custom_btn_text]', array(
	'label'           => esc_html__( 'Button Text:', 'pikture-pro' ),
	'section'         => 'pikture_pro_about_section',
	'active_callback' => 'pikture_pro_is_about_demo_content_disabled',
) );

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'pikture_pro_theme_options[about_custom_btn_text]', array(
		'selector'            => '#about .btn.btn-green',
		'render_callback'     => 'pikture_pro_about_custom_btn_txt_refresh',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

// About custom link control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[about_custom_btn_link]', array(
	'sanitize_callback' => 'esc_url_raw',
	'default'          	=> $options['about_custom_btn_link'],
) );

$wp_customize->add_control( 'pikture_pro_theme_options[about_custom_btn_link]', array(
	'label'           => esc_html__( 'Button Link:', 'pikture-pro' ),
	'section'         => 'pikture_pro_about_section',
	'active_callback' => 'pikture_pro_is_about_custom_content_enable',
) );

/**
 * Content Type: Page.
 */
// About content type page control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[about_page_id]', array(
	'sanitize_callback' => 'pikture_pro_sanitize_page',
) );

$wp_customize->add_control( 'pikture_pro_theme_options[about_page_id]', array(
	'label'             => esc_html__( 'Page:', 'pikture-pro' ),
	'description'             => esc_html__( "Title, content, url and image will be used from the selected page's title, trimmed content, permalink and featured image respectively.", 'pikture-pro' ),
	'active_callback' 	=> 'pikture_pro_is_about_page_content_enable',
	'section'           => 'pikture_pro_about_section',
	'type'				=> 'dropdown-pages',
) );

/**
 * Content type: Post.
 */
// About content type post control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[about_post_id]', array(
	'sanitize_callback' => 'pikture_pro_sanitize_page',
) );

$wp_customize->add_control( new Pikture_Pro_Dropdown_Chooser( $wp_customize, 'pikture_pro_theme_options[about_post_id]', array(
	'label'           => esc_html__( 'Post:', 'pikture-pro' ),
	'description'     => esc_html__( "Title, content, url and image will be rendered from the selected post's title, excerpt, permalink and featured image respectively.", 'pikture-pro' ),
	'active_callback' => 'pikture_pro_is_about_post_content_enable',
	'section'         => 'pikture_pro_about_section',
	'choices'         => pikture_pro_posts_choices(),
) ) );