<?php
/**
 * Portrait options
 *
 * @package Theme Palace
 * @subpackage Pikture Pro
 * @since Pikture Pro 1.0.0
 */

// Add featured section
$wp_customize->add_section( 'pikture_pro_portrait_section', array(
	'title'             => esc_html__( 'Portrait','pikture-pro' ),
	'description'       => esc_html__( 'Portrait options works only on Front page. Images with ratio of 2:3 ( for e.g. 480px by 720px ) would look the best in this section. The Heart This plugin ( i.e. like functionality ) will work only on Content Type: Page, Category and Post.', 'pikture-pro' ),
	'panel'             => 'pikture_pro_front_page_panel',
) );

// Portrait content enable control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[enable_portrait_section]', array(
	'sanitize_callback' => 'pikture_pro_sanitize_switch_control',
	'default'          	=> $options['enable_portrait_section'],
) );

$wp_customize->add_control( new Pikture_Pro_Switch_Control( $wp_customize, 'pikture_pro_theme_options[enable_portrait_section]', array(
	'label'             => esc_html__( 'Portrait Section:', 'pikture-pro' ),
	'section'           => 'pikture_pro_portrait_section',
	'on_off_label' 		=> pikture_pro_switch_options(),
) ) );

// Portrait title control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[portrait_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'          	=> $options['portrait_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'pikture_pro_theme_options[portrait_title]', array(
	'label'             => esc_html__( 'Title:', 'pikture-pro' ),
	'section'           => 'pikture_pro_portrait_section',
	'active_callback' 	=> 'pikture_pro_is_portrait_enable',
) );

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'pikture_pro_theme_options[portrait_title]', array(
		'selector'            => '#portrait .entry-title',
		'render_callback'     => 'pikture_pro_portrait_title',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

// Portrait sub title control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[portrait_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
	'default'          	=> $options['portrait_sub_title'],
) );

$wp_customize->add_control( 'pikture_pro_theme_options[portrait_sub_title]', array(
	'label'             => esc_html__( 'Sub Title:', 'pikture-pro' ),
	'section'           => 'pikture_pro_portrait_section',
	'active_callback' 	=> 'pikture_pro_is_portrait_enable',
) );

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'pikture_pro_theme_options[portrait_sub_title]', array(
		'selector'            => '#portrait .sub-title',
		'render_callback'     => 'pikture_pro_portrait_sub_title',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

// Portrait content type control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[portrait_content_type]', array(
	'sanitize_callback' => 'pikture_pro_sanitize_select',
	'default'          	=> $options['portrait_content_type'],
) );

$wp_customize->add_control( 'pikture_pro_theme_options[portrait_content_type]', array(
	'label'             => esc_html__( 'Content Type:', 'pikture-pro' ),
	'section'           => 'pikture_pro_portrait_section',
	'type'				=> 'radio',
	'active_callback' 	=> 'pikture_pro_is_portrait_enable',
	'choices'			=> pikture_pro_panorama_content_type(),
) );

/**
 * Content type: Gallery.
 */
// Portrait gallery control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[portrait_gallery]', array(
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( new Pikture_Pro_Display_Gallery_Control( $wp_customize, 'pikture_pro_theme_options[portrait_gallery]', array(
	'label'             => esc_html__( 'Gallery:', 'pikture-pro' ),
	'section'           => 'pikture_pro_portrait_section',
	'active_callback' 	=> 'pikture_pro_is_portrait_content_gallery_enable',
) ) );

/**
 * Content type: Category.
 */
// Portrait gallery control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[portrait_category]', array(
	'sanitize_callback' => 'absint',
) );

$wp_customize->add_control( new Pikture_Pro_Dropdown_Category_Control( $wp_customize, 'pikture_pro_theme_options[portrait_category]', array(
	'label'           => esc_html__( 'Category:', 'pikture-pro' ),
	'description'     => esc_html__( "Image and url will be used from the selected category's recent posts' featured image and permalink respectively.", 'pikture-pro' ),
	'section'         => 'pikture_pro_portrait_section',
	'active_callback' => 'pikture_pro_is_portrait_content_category_enable',
	'multiple'        => false,
) ) );

// Counter count control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[portrait_num_of_img]', array(
	'sanitize_callback' => 'pikture_pro_sanitize_number_range',
	'default'          	=> $options['portrait_num_of_img'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'pikture_pro_theme_options[portrait_num_of_img]', array(
	'label'             => esc_html__( 'Number of Posts/Pages: ', 'pikture-pro' ),
	'section'           => 'pikture_pro_portrait_section',
	'type' 				=> 'number',
	'active_callback'	=> 'pikture_pro_is_portrait_content_cat_post_page_enable',
	'input_attrs'		=> array( 'min' => 1, 'max' => 4 ),
) );

for ( $i = 1; $i <= $options['portrait_num_of_img']; $i++ ) { 
	/**
	 * Content Type: Page.
	 */
	// Portrait content type page control and setting
	$wp_customize->add_setting( 'pikture_pro_theme_options[portrait_page_id_'.$i.']', array(
		'sanitize_callback' => 'pikture_pro_sanitize_page',
	) );

	$wp_customize->add_control( 'pikture_pro_theme_options[portrait_page_id_'.$i.']', array(
		'label'             => sprintf( esc_html__( 'Image %d:', 'pikture-pro' ), $i ),
		'description'             => esc_html__( "Image and url will be used from the selected page's featured image and permalink respectively.", 'pikture-pro' ),
		'active_callback' 	=> 'pikture_pro_is_portrait_content_page_enable',
		'section'           => 'pikture_pro_portrait_section',
		'type'				=> 'dropdown-pages',
	) );

	/**
	 * Content Type: Post.
	 */
	// Portrait content type post control and setting
	$wp_customize->add_setting( 'pikture_pro_theme_options[portrait_post_id_'.$i.']', array(
		'sanitize_callback' => 'pikture_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Pikture_Pro_Dropdown_Chooser( $wp_customize, 'pikture_pro_theme_options[portrait_post_id_'.$i.']', array(
		'label'             => sprintf( esc_html__( 'Image %d:', 'pikture-pro' ), $i ),
		'description'             => esc_html__( "Image and url will be used from the selected post's featured image and permalink respectively.", 'pikture-pro' ),
		'active_callback' 	=> 'pikture_pro_is_portrait_content_post_enable',
		'section'           => 'pikture_pro_portrait_section',
		'choices'         => pikture_pro_posts_choices(),
	) ) );
}

// Portrait custom link text control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[portrait_btn_text]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'          	=> $options['portrait_btn_text'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'pikture_pro_theme_options[portrait_btn_text]', array(
	'label'           => esc_html__( 'Button Text:', 'pikture-pro' ),
	'section'         => 'pikture_pro_portrait_section',
	'active_callback' => 'pikture_pro_is_portrait_content_demo_disable',
) );

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'pikture_pro_theme_options[portrait_btn_text]', array(
		'selector'            => '#portrait .btn.btn-green',
		'render_callback'     => 'pikture_pro_portrait_btn_txt_refresh',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

// Portrait custom link control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[portrait_custom_btn_link]', array(
	'sanitize_callback' => 'esc_url_raw',
	'default'          	=> $options['portrait_custom_btn_link'],
) );

$wp_customize->add_control( 'pikture_pro_theme_options[portrait_custom_btn_link]', array(
	'label'           => esc_html__( 'Button Link:', 'pikture-pro' ),
	'section'         => 'pikture_pro_portrait_section',
	'active_callback' => 'pikture_pro_is_portrait_content_cat_demo_disable',
) );