<?php
/**
 * About counter options
 *
 * @package Theme Palace
 * @subpackage Pikture Pro
 * @since Pikture Pro 1.0.0
 */

// Add about temp counter section
$wp_customize->add_section( 'pikture_pro_about_temp_counter', array(
	'title'             => esc_html__( 'Counter','pikture-pro' ),
	'description'       => esc_html__( 'About counter options( Works only on page with "About Us" template assigned. ).', 'pikture-pro' ),
	'panel'             => 'pikture_pro_about_us_panel',
) );

// About counter content enable control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[enable_about_temp_counter]', array(
	'sanitize_callback' => 'pikture_pro_sanitize_switch_control',
	'default'          	=> $options['enable_about_temp_counter'],
) );

$wp_customize->add_control( new Pikture_Pro_Switch_Control( $wp_customize, 'pikture_pro_theme_options[enable_about_temp_counter]', array(
	'label'             => esc_html__( 'Counter:', 'pikture-pro' ),
	'section'           => 'pikture_pro_about_temp_counter',
	'on_off_label' 		=> pikture_pro_switch_options(),
) ) );

// About template counter control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[about_temp_img]', array(
	'sanitize_callback' => 'pikture_pro_sanitize_image',
	'default'          	=> $options['about_temp_img'],
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'pikture_pro_theme_options[about_temp_img]', array(
	'label'             => esc_html__( 'Background Image ', 'pikture-pro' ),
	'active_callback' 	=> 'pikture_pro_is_about_temp_counter_enable',
	'section'           => 'pikture_pro_about_temp_counter',
) ) );

// Number of counter setting and control
$wp_customize->add_setting( 'pikture_pro_theme_options[about_temp_counter_num]', array(
	'sanitize_callback' => 'pikture_pro_sanitize_number_range',
	'default'          	=> $options['about_temp_counter_num'],
) );

$wp_customize->add_control( 'pikture_pro_theme_options[about_temp_counter_num]', array(
	'label'             => esc_html__( 'Number of counters( Max: 5 )', 'pikture-pro' ),
	'section'           => 'pikture_pro_about_temp_counter',
	'type' 				=> 'number',
	'active_callback'	=> 'pikture_pro_is_about_temp_counter_enable',
	'input_attrs'		=> array( 'min' => 1, 'max' => 4 ),
) );

for ( $i=1; $i <= $options['about_temp_counter_num']; $i++ ) { 

	// About counter count control and setting
	$wp_customize->add_setting( 'pikture_pro_theme_options[about_temp_counter_count_'.$i.']', array(
		'sanitize_callback' => 'pikture_pro_sanitize_number_range',
		'default'          	=> $options['about_temp_counter_count'],
	) );

	$wp_customize->add_control( 'pikture_pro_theme_options[about_temp_counter_count_'.$i.']', array(
		'label'             => esc_html__( 'Count ', 'pikture-pro' ) . $i,
		'section'           => 'pikture_pro_about_temp_counter',
		'type' 				=> 'number',
		'active_callback'	=> 'pikture_pro_is_about_temp_counter_enable',
		'input_attrs'		=> array( 'min' => 0 ),
	) );

	// About counter text control and setting
	$wp_customize->add_setting( 'pikture_pro_theme_options[about_temp_counter_text_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'          	=> $options['about_temp_counter_text'],
	) );

	$wp_customize->add_control( 'pikture_pro_theme_options[about_temp_counter_text_'.$i.']', array(
		'label'             => esc_html__( 'Text ', 'pikture-pro' ) . $i,
		'active_callback'	=> 'pikture_pro_is_about_temp_counter_enable',
		'section'           => 'pikture_pro_about_temp_counter',
	) );

	// About counter separator control and setting
	$wp_customize->add_setting( 'pikture_pro_theme_options[about_temp_counter_hr_line_'.$i.']', array(
		'sanitize_callback' => 'pikture_pro_sanitize_html',
	) );

	$wp_customize->add_control( new Pikture_Pro_Customize_Horizontal_Line( $wp_customize, 'pikture_pro_theme_options[about_temp_counter_hr_line_'.$i.']', array(
		'active_callback'	=> 'pikture_pro_is_about_temp_counter_enable',
		'section'           => 'pikture_pro_about_temp_counter',
	) ) );
}