<?php
/**
 * About Us template options
 *
 * @package Theme Palace
 * @subpackage Pikture Pro
 * @since Pikture Pro 1.0.0
 */

// Add about slider section.
$wp_customize->add_section( 'pikture_pro_about_temp_slider', array(
	'title'             => esc_html__( 'Slider','pikture-pro' ),
	'description'       => esc_html__( 'About slider options( Works only on page with "About Us" template assigned. ).', 'pikture-pro' ),
	'panel'             => 'pikture_pro_about_us_panel',
) );

// About slider enable/disable options.
$wp_customize->add_setting( 'pikture_pro_theme_options[enable_about_temp_slider]', array(
	'sanitize_callback' => 'pikture_pro_sanitize_switch_control',
	'default'          	=> $options['enable_about_temp_slider'],
) );

$wp_customize->add_control( new Pikture_Pro_Switch_Control( $wp_customize, 'pikture_pro_theme_options[enable_about_temp_slider]', array(
	'label'             => esc_html__( 'About Slider:', 'pikture-pro' ),
	'section'           => 'pikture_pro_about_temp_slider',
	'on_off_label' 		=> pikture_pro_switch_options(),
) ) );

// About slider content type.
$wp_customize->add_setting( 'pikture_pro_theme_options[about_temp_slider_content_type]', array(
	'sanitize_callback' => 'pikture_pro_sanitize_select',
	'default'          	=> $options['about_temp_slider_content_type'],
) );

$wp_customize->add_control( 'pikture_pro_theme_options[about_temp_slider_content_type]', array(
	'label'             => esc_html__( 'Content Type:', 'pikture-pro' ),
	'section'           => 'pikture_pro_about_temp_slider',
	'type'				=> 'radio',
	'active_callback' 	=> 'pikture_pro_is_about_temp_slider_content_enable',
	'choices'			=> pikture_pro_featured_content_type(),
) );

// Slider number control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[about_temp_slider_num]', array(
	'sanitize_callback' => 'pikture_pro_sanitize_number_range',
	'default'          	=> $options['about_temp_slider_num'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'pikture_pro_theme_options[about_temp_slider_num]', array(
	'label'             => esc_html__( 'Number of sliders ( Max: 5 )', 'pikture-pro' ),
	'section'           => 'pikture_pro_about_temp_slider',
	'type' 				=> 'number',
	'active_callback'	=> 'pikture_pro_is_about_temp_slider_content_demo_disable',
	'input_attrs'		=> array( 'min' => 1, 'max' => 5 ),
) );

$about_temp_slider_num = $options['about_temp_slider_num'];
for ( $i=1; $i <= $about_temp_slider_num; $i++ ) { 
	/**
	 * Content type: Custom.
	 */
	// About slider work control and setting
	$wp_customize->add_setting( 'pikture_pro_theme_options[about_temp_slider_custom_work_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'          	=> $options['about_temp_slider_custom_work'],
	) );

	$wp_customize->add_control( 'pikture_pro_theme_options[about_temp_slider_custom_work_'.$i.']', array(
		'label'             => esc_html__( 'Work ', 'pikture-pro' ) . $i,
		'active_callback' 	=> 'pikture_pro_is_about_temp_slider_content_custom_enable',
		'section'           => 'pikture_pro_about_temp_slider',
	) );

	// About slider title control and setting
	$wp_customize->add_setting( 'pikture_pro_theme_options[about_temp_slider_custom_title_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'          	=> $options['about_temp_slider_custom_title'],
	) );

	$wp_customize->add_control( 'pikture_pro_theme_options[about_temp_slider_custom_title_'.$i.']', array(
		'label'             => esc_html__( 'Title ', 'pikture-pro' ) . $i,
		'active_callback' 	=> 'pikture_pro_is_about_temp_slider_content_custom_enable',
		'section'           => 'pikture_pro_about_temp_slider',
	) );

	// About slider custom content control and setting
	$wp_customize->add_setting( 'pikture_pro_theme_options[about_temp_slider_custom_content_'.$i.']', array(
		'sanitize_callback' => 'pikture_pro_sanitize_html',
		'default'          	=> $options['about_temp_slider_custom_content'],
	) );

	$wp_customize->add_control( 'pikture_pro_theme_options[about_temp_slider_custom_content_'.$i.']', array(
		'label'             => esc_html__( 'Content ', 'pikture-pro' ) . $i,
		'description'     => esc_html__( 'HTML Allowed', 'pikture-pro' ),
		'active_callback' 	=> 'pikture_pro_is_about_temp_slider_content_custom_enable',
		'type'            	=> 'textarea',
		'section'           => 'pikture_pro_about_temp_slider',
	) );

	// About slider custom image control and setting
	$wp_customize->add_setting( 'pikture_pro_theme_options[about_temp_slider_custom_image_'.$i.']', array(
		'sanitize_callback' => 'pikture_pro_sanitize_image',
		'default'          	=> $options['about_temp_slider_custom_image'],
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'pikture_pro_theme_options[about_temp_slider_custom_image_'.$i.']', array(
		'label'             => esc_html__( 'Image ', 'pikture-pro' ) . $i,
		'active_callback' 	=> 'pikture_pro_is_about_temp_slider_content_custom_enable',
		'section'           => 'pikture_pro_about_temp_slider',
	) ) );

	// About slider custom separator control and setting
	$wp_customize->add_setting( 'pikture_pro_theme_options[about_temp_slider_custom_hr_line_'.$i.']', array(
		'sanitize_callback' => 'pikture_pro_sanitize_html',
	) );

	$wp_customize->add_control( new Pikture_Pro_Customize_Horizontal_Line( $wp_customize, 'pikture_pro_theme_options[about_temp_slider_custom_hr_line_'.$i.']', array(
		'active_callback' 	=> 'pikture_pro_is_about_temp_slider_content_custom_enable',
		'section'           => 'pikture_pro_about_temp_slider',
	) ) );

	/**
	 * Content Type: Page.
	 */
	// About slider content type page control and setting
	$wp_customize->add_setting( 'pikture_pro_theme_options[about_temp_slider_page_id_'.$i.']', array(
		'sanitize_callback' => 'pikture_pro_sanitize_page',
	) );

	$wp_customize->add_control( 'pikture_pro_theme_options[about_temp_slider_page_id_'.$i.']', array(
		'label'             => sprintf( esc_html__( 'Slider %d:', 'pikture-pro' ), $i ),
		'description'             => esc_html__( "Text, name and image will be used from the page's content, title and featured image respectively.", 'pikture-pro' ),
		'active_callback' 	=> 'pikture_pro_is_about_temp_slider_content_page_enable',
		'section'           => 'pikture_pro_about_temp_slider',
		'type'				=> 'dropdown-pages',
	) );

	/**
	 * Content Type: Post.
	 */
	// About slider content type post control and setting
	$wp_customize->add_setting( 'pikture_pro_theme_options[about_temp_slider_post_id_'.$i.']', array(
		'sanitize_callback' => 'pikture_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Pikture_Pro_Dropdown_Chooser( $wp_customize, 'pikture_pro_theme_options[about_temp_slider_post_id_'.$i.']', array(
		'label'             => sprintf( esc_html__( 'Slider %d:', 'pikture-pro' ), $i ),
		'description'             => esc_html__( "Text, name and image will be used from the selected post's content, title and featured image respectively.", 'pikture-pro' ),
		'active_callback' 	=> 'pikture_pro_is_about_temp_slider_content_post_enable',
		'section'           => 'pikture_pro_about_temp_slider',
		'choices'         => pikture_pro_posts_choices(),
	) ) );
}