<?php
/**
 * Testimonial options
 *
 * @package Theme Palace
 * @subpackage Pikture Pro
 * @since Pikture Pro 1.0.0
 */

// Add testimonial section
$wp_customize->add_section( 'pikture_pro_testimonial_section', array(
	'title'             => esc_html__( 'Testimonial','pikture-pro' ),
	'description'       => wp_kses_post( sprintf( __( 'Testimonial options works only on Front page. Images with ratio of 2:3 ( for e.g. 720px by 1080px ) would look the best in this section. %1$s %2$sNote:%3$s Position will be displayed only when content type is Custom.', 'pikture-pro' ), '<br />', '<b>', '</b>' ) ),
	'panel'             => 'pikture_pro_front_page_panel',
) );

// Testimonial content enable control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[enable_testimonial_section]', array(
	'sanitize_callback' => 'pikture_pro_sanitize_switch_control',
	'default'          	=> $options['enable_testimonial_section'],
) );

$wp_customize->add_control( new Pikture_Pro_Switch_Control( $wp_customize, 'pikture_pro_theme_options[enable_testimonial_section]', array(
	'label'             => esc_html__( 'Testimonial Section:', 'pikture-pro' ),
	'section'           => 'pikture_pro_testimonial_section',
	'on_off_label' 		=> pikture_pro_switch_options(),
) ) );

// Testimonial left content enable control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[enable_testimonial_left_part]', array(
	'sanitize_callback' => 'pikture_pro_sanitize_switch_control',
	'default'          	=> $options['enable_testimonial_left_part'],
) );

$wp_customize->add_control( new Pikture_Pro_Switch_Control( $wp_customize, 'pikture_pro_theme_options[enable_testimonial_left_part]', array(
	'label'             => esc_html__( 'Testimonial Left part:', 'pikture-pro' ),
	'description'             => esc_html__( 'This is the left descriptive part of the section.', 'pikture-pro' ),
	'section'           => 'pikture_pro_testimonial_section',
	'active_callback' 	=> 'pikture_pro_is_testimonial_enable',
	'on_off_label' 		=> pikture_pro_switch_options(),
) ) );

// Testimonial title control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[testimonial_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'          	=> $options['testimonial_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'pikture_pro_theme_options[testimonial_title]', array(
	'label'             => esc_html__( 'Title:', 'pikture-pro' ),
	'section'           => 'pikture_pro_testimonial_section',
	'active_callback' 	=> 'pikture_pro_is_testimonial_left_part_enable',
) );

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'pikture_pro_theme_options[testimonial_title]', array(
		'selector'            => '#testimonial .entry-title',
		'render_callback'     => 'pikture_pro_testimonial_title',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

// Testimonial sub title control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[testimonial_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
	'default'          	=> $options['testimonial_sub_title'],
) );

$wp_customize->add_control( 'pikture_pro_theme_options[testimonial_sub_title]', array(
	'label'             => esc_html__( 'Sub Title:', 'pikture-pro' ),
	'section'           => 'pikture_pro_testimonial_section',
	'active_callback' 	=> 'pikture_pro_is_testimonial_left_part_enable',
) );

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'pikture_pro_theme_options[testimonial_sub_title]', array(
		'selector'            => '#testimonial .sub-title',
		'render_callback'     => 'pikture_pro_testimonial_sub_title',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

// Testimonial content text
$wp_customize->add_setting( 'pikture_pro_theme_options[testimonial_content]', array(
	'sanitize_callback' => 'pikture_pro_sanitize_html',
	'default'          	=> $options['testimonial_content'],
	'transport'			=> 'postMessage'
) );

$wp_customize->add_control( 'pikture_pro_theme_options[testimonial_content]', array(
	'label'           => esc_html__( 'Content:', 'pikture-pro' ),
	'description'     => esc_html__( 'HTML Allowed', 'pikture-pro' ),
	'section'         => 'pikture_pro_testimonial_section',
	'type'            => 'textarea',
	'active_callback' => 'pikture_pro_is_testimonial_left_part_enable'
) );

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'pikture_pro_theme_options[testimonial_content]', array(
		'selector'            => '.testimonial-content .entry-content',
		'render_callback'     => 'pikture_pro_testimonial_content_refresh',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

// Testimonial separator control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[testimonial_left_part_hr_line]', array(
	'sanitize_callback' => 'pikture_pro_sanitize_html',
) );

$wp_customize->add_control( new Pikture_Pro_Customize_Horizontal_Line( $wp_customize, 'pikture_pro_theme_options[testimonial_left_part_hr_line]', array(
	'active_callback'	=> 'pikture_pro_is_testimonial_left_part_enable',
	'section'           => 'pikture_pro_testimonial_section',
) ) );

// Testimonial content type control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[testimonial_content_type]', array(
	'sanitize_callback' => 'pikture_pro_sanitize_select',
	'default'          	=> $options['testimonial_content_type'],
) );

$wp_customize->add_control( 'pikture_pro_theme_options[testimonial_content_type]', array(
	'label'             => esc_html__( 'Content Type:', 'pikture-pro' ),
	'section'           => 'pikture_pro_testimonial_section',
	'type'				=> 'radio',
	'active_callback' 	=> 'pikture_pro_is_testimonial_enable',
	'choices'			=> pikture_pro_client_content_type(),
) );

// Testimonial count control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[testimonial_num]', array(
	'sanitize_callback' => 'pikture_pro_sanitize_number_range',
	'default'          	=> $options['testimonial_num'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'pikture_pro_theme_options[testimonial_num]', array(
	'label'             => esc_html__( 'Number of Testimonials: ', 'pikture-pro' ),
	'section'           => 'pikture_pro_testimonial_section',
	'type' 				=> 'number',
	'active_callback'	=> 'pikture_pro_is_testimonial_demo_disable',
	'input_attrs'		=> array( 'min' => 1, 'max' => 5 ),
) );

/**
 * Content type: Category.
 */
// Testimonial category control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[testimonial_category]', array(
	'sanitize_callback' => 'absint',
) );

$wp_customize->add_control( new Pikture_Pro_Dropdown_Category_Control( $wp_customize, 'pikture_pro_theme_options[testimonial_category]', array(
	'label'           => esc_html__( 'Category:', 'pikture-pro' ),
	'description'     => esc_html__( "Text, name and image will be used from the selected category's recent posts' excerpt, title and featured image respectively.", 'pikture-pro' ),
	'section'         => 'pikture_pro_testimonial_section',
	'active_callback' => 'pikture_pro_is_testimonial_content_category_enable',
	'multiple'        => false,
) ) );

for ( $i=1; $i <= absint( $options['testimonial_num'] ); $i++ ) { 
	/**
	 * Content type: Custom.
	 */
	// Testimonial custom content control and setting
	$wp_customize->add_setting( 'pikture_pro_theme_options[testimonial_custom_content_'.$i.']', array(
		'sanitize_callback' => 'pikture_pro_sanitize_html',
		'default'          	=> $options['testimonial_custom_content'],
	) );

	$wp_customize->add_control( 'pikture_pro_theme_options[testimonial_custom_content_'.$i.']', array(
		'label'             => esc_html__( 'Content ', 'pikture-pro' ) . $i,
		'description'     => esc_html__( 'HTML Allowed', 'pikture-pro' ),
		'active_callback' 	=> 'pikture_pro_is_testimonial_content_custom_enable',
		'type'            	=> 'textarea',
		'section'           => 'pikture_pro_testimonial_section',
	) );

	// Testimonial custom name control and setting
	$wp_customize->add_setting( 'pikture_pro_theme_options[testimonial_custom_name_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'          	=> $options['testimonial_custom_name'],
	) );

	$wp_customize->add_control( 'pikture_pro_theme_options[testimonial_custom_name_'.$i.']', array(
		'label'             => esc_html__( 'Name ', 'pikture-pro' ) . $i,
		'active_callback' 	=> 'pikture_pro_is_testimonial_content_custom_enable',
		'section'           => 'pikture_pro_testimonial_section',
	) );

	// Testimonial custom position control and setting
	$wp_customize->add_setting( 'pikture_pro_theme_options[testimonial_custom_position_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'          	=> $options['testimonial_custom_position']
	) );

	$wp_customize->add_control( 'pikture_pro_theme_options[testimonial_custom_position_'.$i.']', array(
		'label'             => esc_html__( 'Position ', 'pikture-pro' ) . $i,
		'active_callback' 	=> 'pikture_pro_is_testimonial_content_custom_enable',
		'section'           => 'pikture_pro_testimonial_section',
	) );

	// Testimonial custom image control and setting
	$wp_customize->add_setting( 'pikture_pro_theme_options[testimonial_custom_image_'.$i.']', array(
		'sanitize_callback' => 'pikture_pro_sanitize_image',
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'pikture_pro_theme_options[testimonial_custom_image_'.$i.']', array(
		'label'             => esc_html__( 'Image ', 'pikture-pro' ) . $i,
		'active_callback' 	=> 'pikture_pro_is_testimonial_content_custom_enable',
		'section'           => 'pikture_pro_testimonial_section',
	) ) );


	// Testimonial custom separator control and setting
	$wp_customize->add_setting( 'pikture_pro_theme_options[testimonial_custom_hr_line_'.$i.']', array(
		'sanitize_callback' => 'pikture_pro_sanitize_html',
	) );

	$wp_customize->add_control( new Pikture_Pro_Customize_Horizontal_Line( $wp_customize, 'pikture_pro_theme_options[testimonial_custom_hr_line_'.$i.']', array(
		'active_callback' 	=> 'pikture_pro_is_testimonial_content_custom_enable',
		'section'           => 'pikture_pro_testimonial_section',
	) ) );

	/**
	 * Content Type: Page.
	 */
	// Testimonial content type page control and setting
	$wp_customize->add_setting( 'pikture_pro_theme_options[testimonial_page_id_'.$i.']', array(
		'sanitize_callback' => 'pikture_pro_sanitize_page',
	) );

	$wp_customize->add_control( 'pikture_pro_theme_options[testimonial_page_id_'.$i.']', array(
		'label'             => sprintf( esc_html__( 'Testimonial %d:', 'pikture-pro' ), $i ),
		'description'             => esc_html__( "Text, name and image will be used from the page's trimmed content( i.e. 50 words ), title and featured image respectively.", 'pikture-pro' ),
		'active_callback' 	=> 'pikture_pro_is_testimonial_content_page_enable',
		'section'           => 'pikture_pro_testimonial_section',
		'type'				=> 'dropdown-pages',
	) );

	/**
	 * Content Type: Post.
	 */
	// Testimonial content type post control and setting
	$wp_customize->add_setting( 'pikture_pro_theme_options[testimonial_post_id_'.$i.']', array(
		'sanitize_callback' => 'pikture_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Pikture_Pro_Dropdown_Chooser( $wp_customize, 'pikture_pro_theme_options[testimonial_post_id_'.$i.']', array(
		'label'             => sprintf( esc_html__( 'Testimonial %d:', 'pikture-pro' ), $i ),
		'description'             => esc_html__( "Text, name and image will be used from the selected post's excerpt, title and featured image respectively.", 'pikture-pro' ),
		'active_callback' 	=> 'pikture_pro_is_testimonial_content_post_enable',
		'section'           => 'pikture_pro_testimonial_section',
		'choices'         => pikture_pro_posts_choices(),
	) ) );
}