<?php
/**
 * Call to action section
 *
 * This is the template for the call to action section
 *
 * @package Theme Palace
 * @subpackage Pikture Pro
 * @since 1.0
 */
if ( ! function_exists( 'pikture_pro_add_call_to_action_section' ) ) :
  /**
   * Add call to action section
   *
   *@since Pikture Pro 1.0.0
   */
  function pikture_pro_add_call_to_action_section() {
    // Check if call to action is enabled on frontpage
    $enable_call_to_action_section = apply_filters( 'pikture_pro_section_status', true, 'enable_call_to_action_section' );
    
    if ( true !== $enable_call_to_action_section ) {
        return false;
    }

    // Get call to action section details
    $section_details = array();
    $section_details = apply_filters( 'pikture_pro_filter_call_to_action_section_details', $section_details );

    if ( empty( $section_details ) ) {
      return;
    }

    // Render call to action section now.
    pikture_pro_render_call_to_action_section( $section_details );
  }
endif;
add_action( 'pikture_pro_content_start_action', 'pikture_pro_add_call_to_action_section', 20 );


if ( ! function_exists( 'pikture_pro_get_call_to_action_section_details' ) ) :
  /**
   * call to action section details.
   *
   * @since Pikture Pro 1.0.0
   * @param array $input call to action section details.
   */
  function pikture_pro_get_call_to_action_section_details( $input ) {
    $options = pikture_pro_get_theme_options();

    // Content type.
    $call_to_action_content_type  = $options['call_to_action_content_type'];
    $content = array();
    switch ( $call_to_action_content_type ) {
        case 'demo':
            $demo['title']     = esc_html__( 'Photography is an Art!!', 'pikture-pro' );
            $demo['content']   = esc_html__( 'Proin porta aliquet magna vel gravida. Proin nec fermentum quam. Sed ornare leo et eleifend vulputate. Duis bibendum viverra quam nec sagittis.', 'pikture-pro' );
            $demo['img']       = get_template_directory_uri() . '/assets/uploads/bg-image.jpg';
            $demo['btn_txt']   = esc_html__( 'Hire Me', 'pikture-pro' );
            $demo['btn_url']   = '#';

            // Push to the main array.
            array_push( $content, $demo );
        break;

        case 'custom':
            $custom['title']     = $options['call_to_action_custom_title'];
            $custom['content']   = $options['call_to_action_custom_content'];
            $custom['img']       = ( isset( $options['call_to_action_custom_image'] ) ) ? $options['call_to_action_custom_image'] : '';
            $custom['btn_txt']   = $options['call_to_action_custom_btn_text'];
            $custom['btn_url']   = $options['call_to_action_custom_btn_link'];

            array_push( $content, $custom );
            $content = array_filter( $content );
        break;

        case 'page':
            if ( isset( $options['call_to_action_page_id'] ) ) {
                $id = $options['call_to_action_page_id'];
            }
        break;

        case 'post':
            if ( isset( $options['call_to_action_post_id'] ) ) {
                $id = $options['call_to_action_post_id'];
            }
        break;

        default:
        break;
    }
    if ( 'post' === $call_to_action_content_type || 'page' === $call_to_action_content_type ) {
        if( ! empty ( $id ) ) {
            // Prepare arguments.
            $args = array(
                'post_type'           => $call_to_action_content_type,
                'p'                   => $id,
                'ignore_sticky_posts' => true
            );

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    // Check if it is post or page. If post get excerpt. If page, strip the content.
                    $post_type = get_post_type();
                    $raw_content = pikture_pro_trim_content( 100 ) ;
                    $page_post['content'] = '<p>' . $raw_content . '</p>';
                    
                    $page_post['img']       = get_the_post_thumbnail_url();
                    $page_post['btn_txt']   = $options['call_to_action_custom_btn_text'];
                    $page_post['btn_url']   = get_permalink();

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
                wp_reset_postdata();
            endif;
        }
    }

    if ( ! empty( $content ) ) {
      $input = $content;
    }
    return $input;
  }
endif;
// Call to action section content details.
add_filter( 'pikture_pro_filter_call_to_action_section_details', 'pikture_pro_get_call_to_action_section_details' );


if ( ! function_exists( 'pikture_pro_render_call_to_action_section' ) ) :
  /**
   * Start call to action section
   *
   * @return string Call to action content
   * @since Pikture Pro 1.0.0
   *
   */
   function pikture_pro_render_call_to_action_section( $content_details = array() ) {
        foreach ( $content_details as $content ): ?>
            <div id="call-to-action" class="relative" style="background-image: url('<?php echo esc_html( $content['img'] ); ?>');">
                <div class="overlay"></div>
                <div class="container">
                    <header class="entry-header">
                        <h2 class="entry-title"><?php echo esc_html( $content['title'] ); ?></h2>
                    </header><!-- .entry-header -->

                    <div class="entry-content">
                        <p><?php echo wp_kses_post( $content['content'] ); ?></p>
                    </div><!-- .entry-content -->

                    <?php if ( ! empty( $content['btn_txt'] ) ) : ?>
                        <div class="align-center">
                            <a href="<?php echo esc_url( $content['btn_url'] ); ?>" class="btn btn-white"><?php echo esc_html( $content['btn_txt'] ); ?></a>
                        </div>
                    <?php endif; ?>
                </div><!-- .container -->
            </div><!-- #call-to-action -->
        <?php endforeach;
    }
endif;