<?php
/**
 * Client section
 *
 * This is the template for the client section
 *
 * @package Theme Palace
 * @subpackage Pikture Pro
 * @since 1.0
 */
if ( ! function_exists( 'pikture_pro_add_client_section' ) ) :
  /**
   * Add client section
   *
   *@since Pikture Pro 1.0.0
   */
  function pikture_pro_add_client_section() {
    // Check if client is enabled on frontpage
    $enable_client_section = apply_filters( 'pikture_pro_section_status', true, 'enable_client_section' );
    
    if ( true !== $enable_client_section ) {
        return false;
    }

    // Get client section details
    $section_details = array();
    $section_details = apply_filters( 'pikture_pro_filter_client_section_details', $section_details );

    if ( empty( $section_details ) ) {
      return;
    }

    // Render client section now.
    pikture_pro_render_client_section( $section_details );
  }
endif;
add_action( 'pikture_pro_content_start_action', 'pikture_pro_add_client_section', 20 );


if ( ! function_exists( 'pikture_pro_get_client_section_details' ) ) :
  /**
   * client section details.
   *
   * @since Pikture Pro 1.0.0
   * @param array $input client section details.
   */
  function pikture_pro_get_client_section_details( $input ) {
    $options = pikture_pro_get_theme_options();

    // Content type.
    $client_content_type  = $options['client_content_type'];
    $content = array();
    switch ( $client_content_type ) {
        case 'demo':
            for ( $i = 1; $i < 7; $i++ ) { 
                $demo['img']       = get_template_directory_uri() . '/assets/uploads/client-0'.$i.'.jpg';
                $demo['url'] = '#';

                // Push to the main array.
                array_push( $content, $demo );
            }
        break;

        case 'custom':
            for ( $i=1; $i <= $options['client_num']; $i++ ) {
                $custom['img']       = ( isset( $options['client_custom_image_' . $i ] ) ) ? $options['client_custom_image_' . $i ] : $options['client_custom_image'];
                $custom['url']       = ( isset( $options['client_custom_link_' . $i ] ) ) ? $options['client_custom_link_' . $i ] : $options['client_custom_link' ];

                // Push to the main array.
                array_push( $content, $custom );
            }
        break;

        case 'category':
            if ( isset( $options['client_category'] ) ) {
                $id = $options['client_category'];
            }
        break;

        case 'page':
            $id = array();
            for ( $i=1; $i <= $options['client_num']; $i++ ) {
                if ( isset( $options['client_page_id_' . $i ] ) ) {
                    array_push( $id, $options['client_page_id_' . $i ] );
                }
            }
            // Remove any empty values.
            $id = array_filter( $id );
        break;

        case 'post':
            $id = array();
            for ( $i=1; $i <= $options['client_num']; $i++ ) {
                if ( isset( $options['client_post_id_' . $i ] ) ) {
                    array_push( $id, $options['client_post_id_' . $i ] );
                }
            }
            // Remove any empty values.
            $id = array_filter( $id );
        break;

        default:
        break;
    }
    if ( 'category' === $client_content_type || 'post' === $client_content_type || 'page' === $client_content_type ) {
        if( ! empty ( $id ) ) {
            // Prepare arguments.
            $args = array(
                'ignore_sticky_posts' => true,
                'posts_per_page'      => $options['client_num'],
                'orderby'             => 'post__in'
            );

            $conditional_args = array();
            if ( 'category' === $client_content_type ) {
                $args['cat'] = absint( $id );
            } else {
                $args['post_type'] = $client_content_type;
                $args['post__in']  = $id;
            }

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['img']       = get_the_post_thumbnail_url();
                    $page_post['url']       = get_permalink();

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
                wp_reset_postdata();
            endif;
        }
    }

    if ( ! empty( $content ) ) {
      $input = $content;
    }
    return $input;
  }
endif;
// client section content details.
add_filter( 'pikture_pro_filter_client_section_details', 'pikture_pro_get_client_section_details' );


if ( ! function_exists( 'pikture_pro_render_client_section' ) ) :
  /**
   * Start client section
   *
   * @return string client content
   * @since Pikture Pro 1.0.0
   *
   */
   function pikture_pro_render_client_section( $content_details = array() ) {
        $options        = pikture_pro_get_theme_options();

        $client_content_type  = $options['client_content_type'];
        $anchor_attr = ( 'custom' === $client_content_type ) ? '_blank' : '';

        $dots = ( $options['client_pager_enable'] ) ? 'true' : 'false' ;
        $arrows = ( $options['client_arrows_enable'] ) ? 'true' : 'false' ;
        $autoplay = ( $options['client_autoplay_enable'] ) ? 'true' : 'false' ;
        $infinite = ( $options['client_infinite_enable'] ) ? 'true' : 'false' ;

        $client_bg = isset( $options['client_bg'] ) ? $options['client_bg'] : '' ;

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="client" style="background-image: url('<?php echo esc_url( $client_bg ); ?>');" class="page-section relative">
        <div class="container">

            <header class="entry-header align-center">
                <span class="sub-title"><?php echo esc_html( $options['client_sub_title'] ); ?></span>
                <h2 class="entry-title"><?php echo esc_html( $options['client_title'] ); ?></h2>
                <div class="seperator"></div>
            </header><!-- .entry-header -->

            <div class="regular" data-slick='{
                "slidesToShow": <?php echo absint( $options['client_num_to_show'] ); ?>, "slidesToScroll": 1, 
                "infinite": <?php echo esc_attr( $infinite ); ?>, 
                "speed": 800, 
                "dots": <?php echo esc_attr( $dots ); ?>, 
                "arrows": <?php echo esc_attr( $arrows ); ?>, 
                "autoplay": <?php echo esc_attr( $autoplay ); ?>, 
                "fade": false, 
                "draggable": true }'>
                <?php foreach ($content_details as $content ) : 
                    if ( ! empty( $content['img'] ) ) : ?>
                        <div class="client-slider">
                          <a target="<?php echo esc_attr( $anchor_attr ); ?>" href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['img'] ); ?>"></a>
                        </div><!--.client-slider-->
                    <?php endif; 
                endforeach; ?>
            </div><!-- .regular -->
        </div><!-- .container -->
    </div><!-- #client -->
<?php
    }
endif;