<?php
/**
 * Pikture basic theme structure hooks
 *
 * This file contains structural hooks.
 *
 * @package Theme Palace
 * @subpackage Pikture Pro
 * @since Pikture Pro 1.0.0
 */

$options = pikture_pro_get_theme_options();


if ( ! function_exists( 'pikture_pro_doctype' ) ) :
	/**
	 * Doctype Declaration.
	 *
	 * @since Pikture Pro 1.0.0
	 */
	function pikture_pro_doctype() {
	?>
		<!DOCTYPE html>
			<html <?php language_attributes(); ?>>
	<?php
	}
endif;

add_action( 'pikture_pro_doctype', 'pikture_pro_doctype', 10 );


if ( ! function_exists( 'pikture_pro_head' ) ) :
	/**
	 * Header Codes
	 *
	 * @since Pikture Pro 1.0.0
	 *
	 */
	function pikture_pro_head() {
		?>
		<meta charset="<?php bloginfo( 'charset' ); ?>">
		<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1">
		<link rel="profile" href="http://gmpg.org/xfn/11">
		<?php if ( is_singular() && pings_open( get_queried_object() ) ) : ?>
			<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>">
		<?php endif;
	}
endif;
add_action( 'pikture_pro_before_wp_head', 'pikture_pro_head', 10 );

if ( ! function_exists( 'pikture_pro_page_start' ) ) :
	/**
	 * Page starts html codes
	 *
	 * @since Pikture Pro 1.0.0
	 *
	 */
	function pikture_pro_page_start() {
		?>
		<div id="page" class="site">
			<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'pikture-pro' ); ?></a>

		<?php
	}
endif;

add_action( 'pikture_pro_page_start_action', 'pikture_pro_page_start', 10 );

if ( ! function_exists( 'pikture_pro_page_end' ) ) :
	/**
	 * Page end html codes
	 *
	 * @since Pikture Pro 1.0.0
	 *
	 */
	function pikture_pro_page_end() {
		?>
		</div><!-- #page -->
		<?php
	}
endif;
add_action( 'pikture_pro_page_end_action', 'pikture_pro_page_end', 10 );

if ( ! function_exists( 'pikture_pro_header_start' ) ) :
	/**
	 * Header start html codes
	 *
	 * @since Pikture Pro 1.0.0
	 *
	 */
	function pikture_pro_header_start() {
		?>
		<header id="masthead" class="site-header" role="banner">
			<div id="search">
				<?php get_search_form(); ?>
			</div>
            <div class="container">
		<?php
	}
endif;
add_action( 'pikture_pro_header_action', 'pikture_pro_header_start', 10 );

if ( ! function_exists( 'pikture_pro_site_branding' ) ) :
	/**
	 * Site branding codes
	 *
	 * @since Pikture Pro 1.0.0
	 *
	 */
	function pikture_pro_site_branding() {
		$options  = pikture_pro_get_theme_options();
		$header_txt_logo_extra = $options['header_txt_logo_extra'];		
		?>
		<div class="site-branding">

			<div class="site-logo">
				<?php 
				if ( 'show-all' === $header_txt_logo_extra || 'logo-title' === $header_txt_logo_extra || 'logo-tagline' === $header_txt_logo_extra ) {
					the_custom_logo();
				}
				?> 
			</div><!-- .site-logo -->

			<div class="site-details">
				<?php
				if( 'show-all' === $header_txt_logo_extra  || 'title-only' === $header_txt_logo_extra || 'logo-title' === $header_txt_logo_extra ) {
					if ( pikture_pro_is_latest_posts() ) : ?>
						<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
					<?php else : ?>
						<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
					<?php
					endif;
				} 
				if ( 'show-all' === $header_txt_logo_extra  || 'tagline-only' === $header_txt_logo_extra || 'logo-tagline' === $header_txt_logo_extra ) {
					$description = get_bloginfo( 'description', 'display' );
					if ( $description || is_customize_preview() ) : ?>
						<p class="site-description"><?php echo $description; /* WPCS: xss ok. */ ?></p>
					<?php
					endif; 
				}?>
			</div><!-- .site-details -->
			
		</div><!-- .site-branding -->
		<?php
	}
endif;
add_action( 'pikture_pro_header_action', 'pikture_pro_site_branding', 20 );

if ( ! function_exists( 'pikture_pro_site_navigation' ) ) :
	/**
	 * Site navigation codes
	 *
	 * @since Pikture Pro 1.0.0
	 *
	 */
	function pikture_pro_site_navigation() {
		?>
		<nav id="site-navigation" class="main-navigation" role="navigation">
			<button class="search-icons">
				<?php 
					$options  = pikture_pro_get_theme_options();

					if ( $options['menu_show_search'] ) {
						echo pikture_pro_get_svg( array( 'icon' => 'search' ) );
					}
				
					echo pikture_pro_get_svg( array( 'icon' => 'close' ) );
				 ?>
			</button>
			
			<button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false">
				<?php
				if ( 'bars' === $options['menu_context'] ) {
					echo pikture_pro_get_svg( array( 'icon' => 'bars' ) );
					echo pikture_pro_get_svg( array( 'icon' => 'close' ) );
				} else {
					echo '<span>' . esc_html__( 'Menu', 'pikture-pro' ) . '</span>';
				}
				?>	
			</button>

			<?php wp_nav_menu( array( 
				'fallback_cb'=>'pikture_pro_menu_fallback_cb', 
				'theme_location' => 'primary', 
				'menu_id' => 'primary-menu' 
			) ); ?>
		</nav><!-- #site-navigation -->
		<?php
	}
endif;
add_action( 'pikture_pro_header_action', 'pikture_pro_site_navigation', 30 );

if ( ! function_exists( 'pikture_pro_nav_add_search_form' ) ) :
	/**
	 * Add search form to primary menu.
	 *
	 * @since Pikture Pro 1.0.0
	 *
	 */
	function pikture_pro_nav_add_search_form( $items, $args ) {
	    if( $args->theme_location == 'primary' ){
	        $items .= '<div id="search">' . get_search_form( false ) . '</div>';
	    }
	    return $items;
	}
	add_filter( 'wp_nav_menu_items', 'pikture_pro_nav_add_search_form', 10, 2 );
endif;


/**
 * Add dropdown icon if menu item has children.
 *
 * @param  string $title The menu item's title.
 * @param  object $item  The current menu item.
 * @param  array  $args  An array of wp_nav_menu() arguments.
 * @param  int    $depth Depth of menu item. Used for padding.
 * @return string $title The menu item's title with dropdown icon.
 */
function pikture_pro_dropdown_icon_to_menu_link( $title, $item, $args, $depth ) {
	$options  = pikture_pro_get_theme_options();
	if ( 'primary' === $args->theme_location && 'classic' === $options['menu_type'] ) {
		foreach ( $item->classes as $value ) {
			if ( 'menu-item-has-children' === $value || 'page_item_has_children' === $value ) {
				$title = $title . pikture_pro_get_svg( array( 'icon' => 'angle-down' ) );
			}
		}
	}

	return $title;
}
add_filter( 'nav_menu_item_title', 'pikture_pro_dropdown_icon_to_menu_link', 10, 4 );

if ( ! function_exists( 'pikture_pro_header_end' ) ) :
	/**
	 * Header end html codes
	 *
	 * @since Pikture Pro 1.0.0
	 *
	 */
	function pikture_pro_header_end() {
		?>
			</div>
		</header><!-- #masthead -->
		
		<?php 
		$options  = pikture_pro_get_theme_options();
		$enable_hero_content = $options['enable_hero_content']; 
		$hero_content_text = $options['hero_content_text']; 
		if (  ! empty( $hero_content_text ) && ( pikture_pro_is_frontpage() && 'front-page' === $enable_hero_content  ) || ( 'entire-site' === $enable_hero_content  ) ) : ?>
			<div class="header-content">
			    <h1><?php echo wp_kses_post( $hero_content_text ); ?></h1>
			</div><!-- .header-content -->
		<?php endif; ?>
		<?php
	}
endif;

add_action( 'pikture_pro_header_action', 'pikture_pro_header_end', 50 );

if ( ! function_exists( 'pikture_pro_content_start' ) ) :
	/**
	 * Site content codes
	 *
	 * @since Pikture Pro 1.0.0
	 *
	 */
	function pikture_pro_content_start() {
		?>
		<div id="content" class="site-content">
		<?php
	}
endif;
add_action( 'pikture_pro_site_content', 'pikture_pro_content_start', 10 );

if ( ! function_exists( 'pikture_pro_content_end' ) ) :
	/**
	 * Site content codes
	 *
	 * @since Pikture Pro 1.0.0
	 *
	 */
	function pikture_pro_content_end() {
		?>
		</div><!-- #content -->
		<?php
	}
endif;
add_action( 'pikture_pro_content_end_action', 'pikture_pro_content_end', 10 );

if ( ! function_exists( 'pikture_pro_footer_start' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Pikture Pro 1.0.0
	 *
	 */
	function pikture_pro_footer_start() {
		?>
		<footer id="colophon" class="site-footer" role="contentinfo">
			<div class="container">
            	<div class="inner-wrapper">
		<?php
	}
endif;
add_action( 'pikture_pro_footer', 'pikture_pro_footer_start', 10 );

if ( ! function_exists( 'pikture_pro_footer_site_info' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Theme Palace 1.0
	 *
	 */
	function pikture_pro_footer_site_info() {
		$options  = pikture_pro_get_theme_options();

		$footer_logo = ( isset( $options['footer_logo'] ) ) ? $options['footer_logo'] : '' ;
		$copyright_text = ( isset( $options['copyright_text'] ) ) ? $options['copyright_text'] : '' ;

		$col_class = 'col-1';
		if ( $footer_logo && has_nav_menu( 'social' ) && $copyright_text ) {
			$col_class = 'col-3';
		} elseif ( ( $footer_logo && has_nav_menu( 'social' ) ) || ( $footer_logo && $copyright_text ) || ( has_nav_menu( 'social' ) && $copyright_text ) ) {
			$col_class = 'col-2';
		}
		?>
		<div class="site-info <?php echo esc_attr( $col_class ); ?>">
			<?php if ( $footer_logo ) : ?>
				<div class="hentry">
					<a href="<?php echo esc_url( home_url( '/' ) ); ?>"><img title="<?php esc_html_e( 'Footer Logo', 'pikture-pro' );?>" src="<?php echo esc_url( $footer_logo ); ?>"></a>
				</div>
			<?php endif; ?>

			<?php if ( has_nav_menu( 'social' ) ) : ?>
				<div class="hentry">
					<div class="social-icons">
						<nav class="social-navigation" role="navigation" aria-label="<?php esc_attr_e( 'Footer Social Links Menu', 'pikture-pro' ); ?>">
							<?php
								wp_nav_menu( array(
									'theme_location' => 'social',
									'menu_class'     => 'social-links-menu',
									'depth'          => 1,
									'link_before'    => '<span class="screen-reader-text">',
									'link_after'     => '</span>' . pikture_pro_get_svg( array( 'icon' => 'chain' ) ),
								) );
							?>
						</nav><!-- .social-navigation -->
					</div>
				</div>
			<?php endif;

			if ( $copyright_text ) : ?>
				<div class="hentry copyright">
					<?php 
					echo wp_kses_post( $copyright_text ); 
					if ( function_exists( 'the_privacy_policy_link' ) ) {
					    the_privacy_policy_link( ' | ' );
					}

					?>
				</div><!-- .pull-left -->
			<?php endif; ?>
		</div><!-- .site-info -->
		<?php
	}
endif;
add_action( 'pikture_pro_footer', 'pikture_pro_footer_site_info', 40 );

if ( ! function_exists( 'pikture_pro_footer_scroll_to_top' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Pikture Pro 1.0.0
	 *
	 */
	function pikture_pro_footer_scroll_to_top() {
		$options  = pikture_pro_get_theme_options();
		if ( true === $options['scroll_top_visible'] ) : ?>
			<div class="backtotop"><?php echo pikture_pro_get_svg( array( 'icon' => 'angle-down' ) ); ?></div>
		<?php endif;
	}
endif;
add_action( 'pikture_pro_footer', 'pikture_pro_footer_scroll_to_top', 30 );

if ( ! function_exists( 'pikture_pro_footer_end' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Pikture Pro 1.0.0
	 *
	 */
	function pikture_pro_footer_end() {
		?>
				</div><!-- .inner-wrapper -->
			</div><!-- .container -->
		</footer>
		<?php
	}
endif;
add_action( 'pikture_pro_footer', 'pikture_pro_footer_end', 100 );

if ( ! function_exists( 'pikture_pro_loader' ) ) :
	/**
	 * Start div id #loader
	 *
	 * @since Pikture Pro 1.0.0
	 *
	 */
	function pikture_pro_loader() {
		$options = pikture_pro_get_theme_options();
		if ( $options['loader_enable'] ) { ?>
			<div id="loader">
				<div class="loader-container">
					<?php echo pikture_pro_get_svg( array( 'icon' => esc_attr( $options['loader_icon'] ) ) ); ?>
				</div>	
			</div><!-- end loader -->
		<?php }
	}
endif;
add_action( 'pikture_pro_before_header', 'pikture_pro_loader', 10 );


if ( ! function_exists( 'pikture_pro_add_breadcrumb' ) ) :

	/**
	 * Add breadcrumb.
	 *
	 * @since Pikture Pro 1.0.0
	 */
	function pikture_pro_add_breadcrumb() {

		// Bail if in WooCommerce pages as it has it's own breadcrumb.
		if ( pikture_pro_is_woocommerce_activated() && is_woocommerce() ) {
			return;
		}

		$options = pikture_pro_get_theme_options();
		// Bail if Breadcrumb disabled.
		$breadcrumb = $options['breadcrumb_enable'];
		if ( false === $breadcrumb ) {
			return;
		}
		
		// Bail if Home Page.
		if ( pikture_pro_is_frontpage() ) {
			return;
		}

		echo '<div id="breadcrumb-list" class="os-animation" data-os-animation="fadeInUp">
			<div class="container">';
				/**
				 * pikture_pro_simple_breadcrumb hook
				 *
				 * @hooked pikture_pro_simple_breadcrumb -  10
				 *
				 */
				do_action( 'pikture_pro_simple_breadcrumb' );
		echo '</div><!-- .container -->
			</div><!-- #breadcrumb-list -->';
		return;
	}

endif;
add_action( 'pikture_pro_breadcrumb', 'pikture_pro_add_breadcrumb' , 10 );