<?php
/**
 * Pikture WooCoommerce compatibility hooks.
 *
 * This is the template that includes all WooCoommerce hooks to make the theme compatible with WooCommerce.
 *
 * @package Theme Palace
 * @subpackage Pikture Pro
 * @since Pikture Pro 1.0.0
 */

// Remove the default content wrapper and add theme's content wrapper.
remove_action( 'woocommerce_before_main_content', 'woocommerce_output_content_wrapper', 10 );
add_action( 'woocommerce_before_main_content', 'pikture_pro_woo_output_content_wrapper', 20 );
function pikture_pro_woo_output_content_wrapper() {
	echo '<div class="container clear">
			<div id="primary" class="content-area">
				<main id="main" class="site-main" role="main">';
}

// Add breadcrumb before container.
remove_action( 'woocommerce_before_main_content', 'woocommerce_breadcrumb', 20 );
$options = pikture_pro_get_theme_options();
if ( $options['breadcrumb_enable']) {
	add_action( 'woocommerce_before_main_content', 'woocommerce_breadcrumb', 10 );
}

// Change woo breadcrumb delimiter value as per theme option.
add_filter( 'woocommerce_breadcrumb_defaults' , 'pikture_pro_woo_breadcrumb_defaults' );
function pikture_pro_woo_breadcrumb_defaults() {
	$options = pikture_pro_get_theme_options();
	$sep = $options['breadcrumb_separator'];
	return array(
		'delimiter'   => htmlspecialchars( $sep ),
		'wrap_before' => '<nav class="woocommerce-breadcrumb">',
		'wrap_after'  => '</nav>',
		'before'      => '&#32;',
		'after'       => '&#32;',
		'home'        => esc_html_x( 'Home', 'breadcrumb', 'pikture-pro' ),
	);
}

// Remove the default content end wrapper.
remove_action( 'woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end', 10 );
// Add theme's content end wrapper after sidebar only.
add_action( 'woocommerce_after_main_content', 'pikture_pro_woo_output_content_primary_wrapper_end', 20 );
function pikture_pro_woo_output_content_primary_wrapper_end() {
	echo '</main></div><!-- main end -->';
}
// Add  theme's main container wrapper.
add_action( 'woocommerce_sidebar', 'pikture_pro_woo_output_content_wrapper_end', 20 );
function pikture_pro_woo_output_content_wrapper_end() {
	echo '</div><!-- .container -->';
}


// Remove default sidebar and add custom sidebar.
remove_action( 'woocommerce_sidebar', 'woocommerce_get_sidebar', 10 );
add_action( 'woocommerce_sidebar', 'pikture_pro_woo_get_sidebar', 10 );
function pikture_pro_woo_get_sidebar() {
	$options = pikture_pro_get_theme_options();
	if ( is_active_sidebar( 'woo-sidebar' ) && ( 'no-sidebar' != $options['woo_sidebar_position'] ) ) { ?>
		<aside id="secondary" class="widget-area" role="complementary">
			<?php dynamic_sidebar( 'woo-sidebar' ); ?>
		</aside>
	<?php
	}
}


// Move price above the add-to-cart link and wrap with a wrapper.
remove_action( 'woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_price', 10 );
add_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_price', 7 );
add_action( 'woocommerce_after_shop_loop_item', 'pikture_woo_price_cart_wrapper_start', 6 );
function pikture_woo_price_cart_wrapper_start() {
	echo '<div class="action">';
}

add_action( 'woocommerce_after_shop_loop_item', 'pikture_pro_woo_price_cart_wrapper_end', 15 );
function pikture_pro_woo_price_cart_wrapper_end() {
	echo "</div>";
}

// Remove rating from archive page.
remove_action( 'woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_rating', 5 );

// Change number or products per row to 3
add_filter( 'loop_shop_columns', 'pikture_pro_loop_columns' );
if ( ! function_exists( 'pikture_pro_loop_columns' ) ) {
	function pikture_pro_loop_columns() {
		return 3;
	}
}

/**
 * Modify cart page.
 */
// Move cross-sells below cart_totals.
remove_action( 'woocommerce_cart_collaterals', 'woocommerce_cart_totals', 10 );
add_action( 'woocommerce_cart_collaterals', 'woocommerce_cart_totals', 5 );
remove_action( 'woocommerce_cart_collaterals', 'woocommerce_cross_sell_display', 5 );
add_action( 'woocommerce_cart_collaterals', 'woocommerce_cross_sell_display', 10 );